/*
AI-------------------------------------------------------------------
	List of chatrooms container.
-------------------------------------------------------------------AI
*/
.chatroom-list {
	height: 80%;
	width: 25%;
	display:inline-block;
	background: #fffffe;
	text-align: center;
	overflow: auto;
	border: 1px solid grey;
	padding: 0;
}

/*
AI-------------------------------------------------------------------
	Each item in the chatroom container is a div with the following
	properties.
-------------------------------------------------------------------AI
*/
.chat-list-item {
	padding: 20px 0px;
	border: 1px solid #35b88f;
	background: white;
	width: 99%;
	transition-duration: 0.5s;
}

.chat-list-item:hover {
	background: #ededed;
}

.chat-link {
	color: black;
	text-decoration: none;
	transition-duration: 0.5s;
}

.chat-link:hover {
	text-decoration: none;
}
/*The search bar settings are here.*/
.search {
	margin-top: auto;
	margin-bottom: auto;
	display: inline-block;
	width: 25vw;
}

.room-name {
	margin-top: auto;
	margin-bottom: auto;
	display: inline-block;
	width: 70vw;
	text-align: center;
}

@media only screen and (max-width: 768px) {
	.chatroom-list {
		display: none;
		width: 90%;
	}
	.search {
		display: none;
	}
}

@media only screen and (min-width: 769px) {
	.chatroom-list {
		display: inline-block;
		width: 20%;
	}
	.search {
		width: 20%;
	}
}