{# {% extends 'base.html' %} <!--Site level base template as defined in your app settings--> #}

<!--AI==========================================================
	This is the Base for all pages in the chat app. It contains
	the following CSS stylesheets:
		1) Bootstrap 4.1.2
		2) Chat app
		3) JQuery UI for formatting autocomplete elements proper
	and the following JS scripts:
		1) BootStrap 4.1.2
		2) JQuery
		3) JQuery UI
===========================================================AI-->
{% load static %}
<!-- <html> -->
	{% block extrahead %}
	{{ block.super }}
		<meta charset="UTF-8">

		<!--Mobile first viewport tag-->
		<meta name="viewport"
		content="width=device-width, initial-scale=1, shrink-to-fit=no">

		<!--JQuery JS-->
		<script src = "https://code.jquery.com/jquery-3.3.1.min.js"></script>

		<!--FontAwesome-->
		<link rel="stylesheet" href="https://use.fontawesome.com/releases/v5.3.1/css/all.css"
		integrity="sha384-mzrmE5qonljUremFsqc01SB46JvROS7bZs3IO2EmfFsd15uHvIt+Y8vEf7N7fWAU"
		crossorigin="anonymous">

		<!--AI======================================================================
			We use JQuery UI to use its autocomplete function to dynamically
			produce a list of registered users for the current user to look through.
		=======================================================================AI-->
		<!--JQuery UI CSS-->
		<link rel="stylesheet" href="//code.jquery.com/ui/1.12.1/themes/base/jquery-ui.css">
		<!--JQuery UI JS-->
		<script src="https://code.jquery.com/ui/1.12.1/jquery-ui.js"></script>

		<!--AI==========================================================
			Chat App's CSS stylesheet link.
		===========================================================AI-->
		<link rel="stylesheet" href="{% static 'css/base.css' %}">
	{% endblock extrahead %}

		<!--AI==========================================================
			Child pages inherting this base must include their extra
			properties inside the following content block.
		===========================================================AI-->
		{% block content %}
		{% endblock content %}
